#!/bin/bash
cd $(dirname $0)

# Read config file
source "/etc/hovding-data-collector.conf"
source "static.config"

# include common functions
source $common_functions

log "Starting data collection"
DEVNAME=$1
DEVNUM=$2
PID=$3


arch=$(uname -m)

# make setting from config lowercase
PID0301="${PID0301,,}"
PID1001="${PID1001,,}"
PID2001="${PID2001,,}"
PID2003="${PID2003,,}"

case $PID in
	"0301")
		if [[ $PID0301 == "off" ]]; then
			warning="Auto extract from PID $PID not enabled"
			if [[ $DEVNAME != "manual" ]]; then
				cleanexit
			fi
		fi
	;;
	"1001")
		if [[ $PID1001 == "off" ]]; then
			warning="Auto extract from PID $PID not enabled"
			if [[ $DEVNAME != "manual" ]]; then
				cleanexit
			fi
		fi
	;;
	"2001")
		if [[ $PID2001 == "off" ]]; then
			warning="Auto extract from PID $PID not enabled"
			if [[ $DEVNAME != "manual" ]]; then
				cleanexit
			fi
		fi
	;;
	"2003")
		if [[ $PID2003 == "off" ]]; then
			warning="Auto extract from PID $PID not enabled"
			if [[ $DEVNAME != "manual" ]]; then
				cleanexit
			fi
		fi
	;;
	
	*)
		error "Script started with unsupported arguments"
	;;
esac
	
if [[ $DEVNAME != "manual" ]]; then
	# collar seems to restart sometimes, wait and see that it is still available on the same dev-id
	sleep 2
fi

if [[ ! -e $DEVNAME && $DEVNAME != "manual" ]]; then
	dlog "Exiting, device $DEVNUM no longer available"
	exit 1
else
	dlog "Using $DEVNUM, $DEVNAME"
fi

dlog "Checking date"
while [[ "$(date +%Y)" -lt 2017 ]]; do
	## check if the collar is still there, if not exit.
	if [ ! -e $DEVNAME ]; then
		dlog "Exiting, device $DEVNUM no longer available"
		exit 1
	fi
	dlog "Waiting for date to be set"
	sleeping 5
done

# test to see if sd card is mounted and that we have the login key.
if [ -e $keyfile ]; then
	dlog "Key file exists"
else
	while [[ ! -e "$keyfile" ]]; do
		uptime=$(cat /proc/uptime | sed -e 's/^\([0-9]*\)\..*/\1/')
		dlog "Uptime $uptime"
		if [[ "$uptime" -gt 300 ]]; then
			error "Missing key file after 5 min, aborting."
		else
			sleeping 5
		fi
	done
fi

if [[ $arch == "armv7l" ]]; then
	# indicate that we are busy working with the collar
	echo "0" > /sys/class/leds/opi\:green\:usr2/brightness
	echo "heartbeat" > /sys/class/leds/opi\:red\:usr3/trigger

	# just have some time here to make sure it is not missed
	sleep 5
fi

# Overwrite old config file
echo "## Autogenerated config for used by 'run-parts' scirpts." > $live_cfg

#Create target data dir
if [[ "$arch" == "armv7l" ]]
then
	datadir="/var/opi/datacollector/$PID"
else
	datadir="/tmp/datacollector/$PID"
fi

echo "datadir=\"$datadir\"" >> $live_cfg

CWD=$(pwd)
echo "CWD=\"$CWD\"" >> $live_cfg


case $PID in
	"0301")
		dlog "Running scripts for Herkules prototype units"

		;;

	"1001")
		dlog "Setup extraction for Herkules production units"
		;;

	"2003")
		dlog "Setup extraction for Vega prototype units"
		;;

	"2001")
		dlog "Setup extraction for Vega production units"
		;;

	*)
		error "Unknown PID, exit"
		;;
esac

# Run script specific to this PID	
dlog "Running PID scripts"
run-parts -v "scripts/$PID"
if [[ $? -ne 0 ]]; then
	error "Failed to run scripts for PID '$PID'"
fi

# Run common scripts
log "Running common scripts"
run-parts -v "scripts/common"
if [[ $? -ne 0 ]]; then
	error "Failed to run common scripts (currnt PID '$PID')"
fi

cleanexit


